// Photoshop Script to arrange layers into a 3x5 grid with 10px spacing

// Function to rearrange layers
function arrangeLayers(cols, rows, spacing) {
    var doc = app.activeDocument;
    var layerCount = doc.artLayers.length;
    var index = 0;

    // Calculate the size of each layer (assuming all layers are of the same size)
    var layerWidth = doc.width;
    var layerHeight = doc.height;

    // Resize canvas to fit all layers in the new arrangement
    var totalWidth = (layerWidth + spacing) * cols - spacing;
    var totalHeight = (layerHeight + spacing) * rows - spacing;
    doc.resizeCanvas(totalWidth, totalHeight, AnchorPosition.TOPLEFT);

    for (var row = 0; row < rows; row++) {
        for (var col = 0; col < cols; col++) {
            if (index >= layerCount) break;

            // Calculate position for each layer
            var xPosition = (layerWidth + spacing) * col;
            var yPosition = (layerHeight + spacing) * row;

            // Move the layer to the calculated position
            var layer = doc.artLayers[index];
            layer.visible = true;
            doc.activeLayer = layer;
            layer.translate(xPosition, yPosition);

            index++;
        }
    }
}

// Main
if (app.documents.length > 0) {
    arrangeLayers(3, 5, 10); // 3 columns, 5 rows, 10px spacing
} else {
    alert("No documents are open.");
}